@@ -1,5 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.pool import Pool, PoolMeta
 
@@ -19,11 +19,15 @@ class Product:
     def search_rec_name(cls, name, clause):
         ProductCode = Pool().get('product.product.code')
 
-        ids = map(int, cls.search([('code',) + clause[1:]], order=[]))
-        ids += map(int, cls.search([('template.name',) + clause[1:]], order=[]))
+        ids = map(int, cls.search([('code',) + tuple(clause[1:])], order=[]))
+        ids += map(int, cls.search(
+            [('template.name',) + tuple(clause[1:])], order=[]
+        ))
 
         if not ids:
-            codes = ProductCode.search([('code',) + clause[1:]], order=[])
+            codes = ProductCode.search(
+                [('code',) + tuple(clause[1:])], order=[]
+            )
             ids += map(int, cls.search([('codes', 'in', map(int, codes))]))
 
         return [('id', 'in', ids)]
